@@ -12,28 +12,28 @@ def safe_json_dumps(obj):
     return obj
 
 
-async def async_make_request(url, payload, headers=None):
+async def async_make_request(url, payload, headers=None,logger=logging):
     # Log the payload and headers for debugging
-    logging.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
+    logger.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
     
     async with httpx.AsyncClient(timeout=1000) as client:
         # Use json=payload instead of data= to ensure correct encoding and headers
         response = await client.post(url, json=payload, headers=headers)
         
         # Log the response status and content
-        logging.debug(f"Received response: {response.status_code} - {response.text}")
+        logger.debug(f"Received response: {response.status_code} - {response.text}")
         
         response.raise_for_status()  # Raise exception for non-2xx status codes
         return response  # Return the full response if needed
 
 
-def make_request(url, payload, headers=None):
+def make_request(url, payload, headers=None,logger=logging):
     # Log the payload and headers for debugging
-    logging.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
+    logger.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
     # Use json=payload instead of data= to ensure correct encoding and headers
     response = requests.post(url, data=safe_json_dumps(payload), headers=headers)
     # Log the response status and content
-    logging.debug(f"Received response: {response.status_code} - {response.text}")
+    logger.debug(f"Received response: {response.status_code} - {response.text}")
     return response  # Return the full response if needed
 
 
@@ -45,7 +45,8 @@ def get_kwargs_bools(key, bools, **kwargs):
 
 def get_solcatcherSettings(getApi=False, **kwargs):
     bools = {}
-    
+    bools, kwargs = get_kwargs_bools(key='logger', bools=bools, **kwargs)
+    logger = kwargs.get('logger') or logging
     bools, kwargs = get_kwargs_bools(key='solcatcherSettings', bools=bools, **kwargs)
     bools, kwargs = get_kwargs_bools(key='headers', bools=bools, **kwargs)
     headers = bools.get('headers', get_headers())
@@ -57,7 +58,7 @@ def get_solcatcherSettings(getApi=False, **kwargs):
             apiKey = None
         headers = get_db_header(headers=headers, api_key=apiKey)
     headers = headers or get_headers()
-    return kwargs, bools.get('solcatcherSettings'), headers, bools
+    return kwargs, bools.get('solcatcherSettings'), headers, bools,logger
 
 def get_response_option(response, option='json'):
     """
@@ -98,32 +99,32 @@ def runSolcatcherSettings(response, solcatcherSettings):
     return response
 def process_settings(*args, **kwargs):
     kwargs["solcatcherSettings"] = kwargs.get("solcatcherSettings") or {"getResponse":True,"getResult":True}
-    kwargs, solcatcherSettings, headers, bools = get_solcatcherSettings(**kwargs)
+    kwargs, solcatcherSettings, headers, bools,logger = get_solcatcherSettings(**kwargs)
     payload = get_payload(*args, **kwargs)
-    return kwargs, solcatcherSettings, headers, bools, payload
+    return kwargs, solcatcherSettings, headers, bools, payload,logger
 async def async_call_solcatcher_ts(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherTsUrl(endpoint=endpoint)
-    response = await async_make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 async def async_call_solcatcher_py(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherPairCatchUrl(endpoint=endpoint)
-    response = await async_make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 async def async_call_solcatcher_db(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherDbCalls(endpoint=endpoint)
-    response = await async_make_request(url, payload, headers=headers)
+    response = await async_make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 
-async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,**kwargs):
+async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,logger=logging,**kwargs):
     """
     A rate-limited caller that funnels into makeLimitedRpcCall.
     """
@@ -132,17 +133,17 @@ async def async_call_rate_limiter(method, params=None, url_1_only=None, url_2_on
     url_2_only = False if url_2_only is None else url_2_only
     unique_item = params[0] if params else params
     try:
-        logging.debug(f"Fetching transaction for signature={unique_item}")
+        logger.debug(f"Fetching transaction for signature={unique_item}")
         response = await async_make_rate_limited_call(method=method, params=params,
                                             url_1_only=url_1_only,
                                             url_2_only=url_2_only,
                                             **kwargs)
-        logging.debug(f"Raw response from {method} for {unique_item}.")
+        logger.debug(f"Raw response from {method} for {unique_item}.")
         return response
     except Exception as e:
-        logging.error(f"Error fetching {method}: {e}")
+        logger.error(f"Error fetching {method}: {e}")
         return []
-def call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,**kwargs):
+def call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,logger=logging,**kwargs):
     """
     A rate-limited caller that funnels into makeLimitedRpcCall.
     """
@@ -151,17 +152,17 @@ def call_rate_limiter(method, params=None, url_1_only=None, url_2_only=None,**kw
     url_2_only = False if url_2_only is None else url_2_only
     unique_item = params[0] if params else params
     try:
-        logging.debug(f"Fetching transaction for signature={unique_item}")
+        logger.debug(f"Fetching transaction for signature={unique_item}")
         response = make_rate_limited_call(method=method, params=params,
                                             url_1_only=url_1_only,
                                             url_2_only=url_2_only,
                                             **kwargs)
-        logging.debug(f"Raw response from {method} for {unique_item}.")
+        logger.debug(f"Raw response from {method} for {unique_item}.")
         return response
     except Exception as e:
-        logging.error(f"Error fetching {method}: {e}")
+        logger.error(f"Error fetching {method}: {e}")
         return []
-async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args,**kwargs):
+async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,logger=logging,*args,**kwargs):
     """
     Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
     After the 1st attempt, set url_1_only=False.
@@ -170,7 +171,7 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     solcatcherSettings=defaultSolcatcherSettings
     solcatcherSettings.update(ogsettings)
     kwargs['solcatcherSettings']=solcatcherSettings
-    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
+    kwargs,solcatcherSettings,headers,bools,logger = get_solcatcherSettings(**kwargs)
     for attempt in range(3):  # Retry logic
         if attempt == 2:
             url_2_only = True
@@ -209,7 +210,7 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
     # If no response after all attempts, return empty or raise an exception
     return []
 
-def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*args,**kwargs):
+def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,logger=logging,*args,**kwargs):
     """
     Attempt up to 3 times. After the 2nd attempt, set url_2_only=True.
     After the 1st attempt, set url_1_only=False.
@@ -218,7 +219,7 @@ def make_rate_limited_call(method, params, url_1_only=True, url_2_only=False,*ar
     solcatcherSettings=defaultSolcatcherSettings
     solcatcherSettings.update(ogsettings)
     kwargs['solcatcherSettings']=solcatcherSettings
-    kwargs,solcatcherSettings,headers,bools = get_solcatcherSettings(**kwargs)
+    kwargs,solcatcherSettings,headers,bools,logger = get_solcatcherSettings(**kwargs)
     for attempt in range(3):  # Retry logic
         if attempt == 2:
             url_2_only = True
@@ -264,27 +265,26 @@ def get_url_request(url=None, payload={}, headers=None, url_1_only=None, url_2_o
             url = fall_back_rpc
     url = url or solana_rpc_url
     return url
-def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
+def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,logger=logging,*args, **kwargs):
     return call_rate_limiter(method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs)
 
 def call_solcatcher_ts(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherTsUrl(endpoint=endpoint)
-    response = make_request(url, payload, headers=headers)
+    response = make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 def call_solcatcher_py(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherPairCatchUrl(endpoint=endpoint)
-    response = make_request(url, payload, headers=headers)
+    response = make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
 
 def call_solcatcher_db(endpoint, *args, **kwargs):
-    kwargs, solcatcherSettings, headers, bools, payload = process_settings(*args, **kwargs)
+    kwargs, solcatcherSettings, headers, bools, payload,logger = process_settings(*args, **kwargs)
     url = getSolcatcherDbCalls(endpoint=endpoint)
-    response = make_request(url, payload, headers=headers)
+    response = make_request(url, payload, headers=headers,logger=logger)
     result = runSolcatcherSettings(response, solcatcherSettings)
     return result
-
